@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2004-2006 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 2004-2007 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -28,7 +28,7 @@
  * Contains the class "t3lib_db" containing functions for building SQL queries and mysql wrappers, thus providing a foundational API to all database interaction.
  * This class is instantiated globally as $TYPO3_DB in TYPO3 scripts.
  *
- * $Id: class.t3lib_db.php 1761 2006-10-14 18:51:22Z liels_bugs $
+ * $Id: class.t3lib_db.php 1953 2007-01-28 20:29:09Z masi $
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  */
@@ -551,11 +551,7 @@ class t3lib_DB {
 	 * @see quoteStr()
 	 */
 	function fullQuoteStr($str, $table)	{
-		if (function_exists('mysql_real_escape_string'))	{
-			return '\''.mysql_real_escape_string($str, $this->link).'\'';
-		} else {
-			return '\''.mysql_escape_string($str).'\'';
-		}
+		return '\''.mysql_real_escape_string($str, $this->link).'\'';
 	}
 
 	/**
@@ -595,11 +591,7 @@ class t3lib_DB {
 	 * @see quoteStr()
 	 */
 	function quoteStr($str, $table)	{
-		if (function_exists('mysql_real_escape_string'))	{
-			return mysql_real_escape_string($str, $this->link);
-		} else {
-			return mysql_escape_string($str);
-		}
+		return mysql_real_escape_string($str, $this->link);
 	}
 
 	/**
@@ -787,6 +779,7 @@ class t3lib_DB {
 	 * @return	integer		Number of resulting rows.
 	 */
 	function sql_num_rows($res)	{
+		$this->debug_check_recordset($res);
 		return mysql_num_rows($res);
 	}
 
@@ -799,6 +792,7 @@ class t3lib_DB {
 	 * @return	array		Associative array of result row.
 	 */
 	function sql_fetch_assoc($res)	{
+		$this->debug_check_recordset($res);
 		return mysql_fetch_assoc($res);
 	}
 
@@ -812,6 +806,7 @@ class t3lib_DB {
 	 * @return	array		Array with result rows.
 	 */
 	function sql_fetch_row($res)	{
+		$this->debug_check_recordset($res);
 		return mysql_fetch_row($res);
 	}
 
@@ -824,6 +819,7 @@ class t3lib_DB {
 	 * @return	boolean		Returns TRUE on success or FALSE on failure.
 	 */
 	function sql_free_result($res)	{
+		$this->debug_check_recordset($res);
 		return mysql_free_result($res);
 	}
 
@@ -859,6 +855,7 @@ class t3lib_DB {
 	 * @return	boolean		Returns TRUE on success or FALSE on failure.
 	 */
 	function sql_data_seek($res,$seek)	{
+		$this->debug_check_recordset($res);
 		return mysql_data_seek($res,$seek);
 	}
 
@@ -872,6 +869,7 @@ class t3lib_DB {
 	 * @return	string		Returns the name of the specified field index
 	 */
 	function sql_field_type($res,$pointer)	{
+		$this->debug_check_recordset($res);
 		return mysql_field_type($res,$pointer);
 	}
 
@@ -895,7 +893,7 @@ class t3lib_DB {
 		if (!$this->link) {
 			t3lib_div::sysLog('Could not connect to Mysql server '.$TYPO3_db_host.' with user '.$TYPO3_db_username.'.','Core',4);
 		} else {
-			$setDBinit = t3lib_div::trimExplode(chr(10), $GLOBALS['TYPO3_CONF_VARS']['SYS']['setDBinit'],true);
+			$setDBinit = t3lib_div::trimExplode(chr(10), $GLOBALS['TYPO3_CONF_VARS']['SYS']['setDBinit'],TRUE);
 			foreach ($setDBinit as $v)	{
 				if (mysql_query($v, $this->link) === FALSE)	{
 					t3lib_div::sysLog('Could not initialize DB connection with query "'.$v.'": '.mysql_error($this->link),'Core',3);
@@ -1096,6 +1094,33 @@ class t3lib_DB {
 			));
 		}
 	}
+
+	/**
+	 * Checks if recordset is valid and writes debugging inormation into devLog if not.
+	 * 
+	 * @param	resource	$res	Recordset
+	 * @return	boolean	<code>false</code> if recordset is not valid
+	 */
+	function debug_check_recordset($res) {
+		if (!$res) {
+			$trace = FALSE;
+			$msg = 'Invalid database result resource detected';
+  			$trace = debug_backtrace();
+			array_shift($trace);
+			$cnt = count($trace);
+			for ($i=0; $i<$cnt; $i++)	{
+					// complete objects are too large for the log
+				if (isset($trace['object']))	unset($trace['object']);
+			}
+			$msg .= ': function t3lib_DB->' . $trace[0]['function'] . ' called from file ' . substr($trace[0]['file'],strlen(PATH_site)+2) . ' in line ' . $trace[0]['line'];
+			t3lib_div::sysLog($msg.'. Use a devLog extension to get more details.', 'Core/t3lib_db', 3);
+			t3lib_div::devLog($msg.'.', 'Core/t3lib_db', 3, $trace);
+
+			return FALSE;
+		}
+		return TRUE;
+	}
+
 }
 
 
