@@ -1,5 +1,5 @@
 <?php
-# TYPO3 CVS ID: $Id: ext_tables.php 1421 2006-04-10 09:27:15Z mundaun $
+# TYPO3 CVS ID: $Id: ext_tables.php 2063 2007-02-20 21:43:00Z mundaun $
 if (!defined ('TYPO3_MODE')) 	die ('Access denied.');
 
 if (TYPO3_MODE=='BE')	{
@@ -87,6 +87,7 @@ if (TYPO3_MODE=='BE')	{
 
 	// Adding default value columns:
 	$TCA['pages']['ctrl']['useColumnsForDefaultValues'].=',fe_group,hidden';
+	$TCA['pages']['ctrl']['transForeignTable'] = 'pages_language_overlay';
 
 	// Adding new columns:
 	$TCA['pages']['columns'] = array_merge($TCA['pages']['columns'],Array(
@@ -399,7 +400,7 @@ if (TYPO3_MODE=='BE')	{
 				'type' => 'group',
 				'internal_type' => 'file',
 				'allowed' => $GLOBALS['TYPO3_CONF_VARS']['GFX']['imagefile_ext'].',html,htm,ttf,txt,css',
-				'max_size' => '2000',
+				'max_size' => $GLOBALS['TYPO3_CONF_VARS']['BE']['maxFileSize'],
 				'uploadfolder' => 'uploads/media',
 				'show_thumbs' => '1',
 				'size' => '3',
@@ -513,7 +514,7 @@ $TCA['tt_content'] = Array (
 		'prependAtCopy' => 'LLL:EXT:lang/locallang_general.php:LGL.prependAtCopy',
 		'copyAfterDuplFields' => 'colPos,sys_language_uid',
 		'useColumnsForDefaultValues' => 'colPos,sys_language_uid',
-		'shadowColumnsForNewPlaceholders' => 'sys_language_uid,l18n_parent,colPos,header',
+		'shadowColumnsForNewPlaceholders' => 'colPos',
 		'transOrigPointerField' => 'l18n_parent',
 		'transOrigDiffSourceField' => 'l18n_diffsource',
 		'languageField' => 'sys_language_uid',
@@ -633,7 +634,7 @@ $TCA['pages_language_overlay'] = Array (
 		'transOrigPointerField' => 'pid',
 		'transOrigPointerTable' => 'pages',
 		'transOrigDiffSourceField' => 'l18n_diffsource',
-		'shadowColumnsForNewPlaceholders' => 'sys_language_uid,title',
+		'shadowColumnsForNewPlaceholders' => 'title',
 		'languageField' => 'sys_language_uid',
 		'mainpalette' => 1,
 		'dynamicConfigFile' => t3lib_extMgm::extPath($_EXTKEY).'tbl_cms.php'
