@@ -27,7 +27,7 @@
 /**
  * Index search frontend
  *
- * $Id: class.tx_indexedsearch.php 1791 2006-11-16 20:47:27Z masi $
+ * $Id: class.tx_indexedsearch.php 2158 2007-02-27 13:49:53Z ohader $
  *
  * Creates a searchform for indexed search. Indexing must be enabled
  * for this to make sense.
@@ -682,7 +682,7 @@ class tx_indexedsearch extends tslib_pibase {
 			// Print a message telling which words we searched for, and in which sections etc.
 		$what = $this->tellUsWhatIsSeachedFor($sWArr).
 				(substr($this->piVars['sections'],0,2)=='rl'?' '.$this->pi_getLL('inSection','',1).' "'.substr($this->getPathFromPageId(substr($this->piVars['sections'],4)),1).'"':'');
-		$what = '<div'.$this->pi_classParam('whatis').'><p>'.$what.'</p></div>';
+		$what = '<div'.$this->pi_classParam('whatis').'>'.$this->cObj->stdWrap($what, $this->conf['whatis_stdWrap.']).'</div>';
 		$content = $what.$content;
 
 			// Return content:
@@ -820,23 +820,23 @@ class tx_indexedsearch extends tslib_pibase {
 
 				// Perform search for word:
 			switch($theType)	{
-				case '1':
+				case '1':	// Part of word
 					$wSel = "IW.baseword LIKE '%".$GLOBALS['TYPO3_DB']->quoteStr($sWord, 'index_words')."%'";
 					$res = $this->execPHashListQuery($wSel,' AND is_stopword=0');
 				break;
-				case '2':
+				case '2':	// First part of word
 					$wSel = "IW.baseword LIKE '".$GLOBALS['TYPO3_DB']->quoteStr($sWord, 'index_words')."%'";
 					$res = $this->execPHashListQuery($wSel,' AND is_stopword=0');
 				break;
-				case '3':
+				case '3':	// Last part of word
 					$wSel = "IW.baseword LIKE '%".$GLOBALS['TYPO3_DB']->quoteStr($sWord, 'index_words')."'";
 					$res = $this->execPHashListQuery($wSel,' AND is_stopword=0');
 				break;
-				case '10':
+				case '10':	// Sounds like
 					$wSel = 'IW.metaphone = '.$this->indexerObj->metaphone($sWord);
 					$res = $this->execPHashListQuery($wSel,' AND is_stopword=0');
 				break;
-				case '20':
+				case '20':	// Sentence
 					$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
 								'ISEC.phash',
 								'index_section ISEC, index_fulltext IFT',
@@ -849,7 +849,7 @@ class tx_indexedsearch extends tslib_pibase {
 
 					if ($this->piVars['type']==20)	$this->piVars['order'] = 'mtime';		// If there is a fulltext search for a sentence there is a likeliness that sorting cannot be done by the rankings from the rel-table (because no relations will exist for the sentence in the word-table). So therefore mtime is used instaed. It is not required, but otherwise some hits may be left out.
 				break;
-				default:
+				default:	// Distinct word
 					$wSel = 'IW.wid = '.$hash = $this->indexerObj->md5inthash($sWord);
 					$res = $this->execPHashListQuery($wSel,' AND is_stopword=0');
 				break;
@@ -1324,7 +1324,7 @@ class tx_indexedsearch extends tslib_pibase {
 			$html = $this->cObj->substituteSubpart($html, '###ADDITONAL_KEYWORD###', '');
 		}
 
-		$markerArray['###ACTION_URL###'] = $this->pi_getPageLink($GLOBALS['TSFE']->id, $GLOBALS['TSFE']->sPre);
+		$markerArray['###ACTION_URL###'] = htmlspecialchars($this->pi_getPageLink($GLOBALS['TSFE']->id, $GLOBALS['TSFE']->sPre));
 
 		$hiddenFieldCode = $this->cObj->getSubpart($this->templateCode, '###HIDDEN_FIELDS###');
 		$hiddenFieldCode = preg_replace('/^\n\t(.+)/ms', '$1', $hiddenFieldCode);		// Remove first newline and tab (cosmetical issue)
@@ -2066,9 +2066,12 @@ class tx_indexedsearch extends tslib_pibase {
 	 * @return	array		Modified template array
 	 */
 	function makeInfo($row,$tmplArray)	{
+		$dateFormat = $GLOBALS['TYPO3_CONF_VARS']['SYS']['ddmmyy'];
+		$timeFormat = $GLOBALS['TYPO3_CONF_VARS']['SYS']['hhmm'];
+
 		$tmplArray['size'] = t3lib_div::formatSize($row['item_size']);
-		$tmplArray['created'] = date('d-m-y',$row['item_crdate']);
-		$tmplArray['modified'] = date('d-m-y H:i',$row['item_mtime']);
+		$tmplArray['created'] = date($dateFormat, $row['item_crdate']);
+		$tmplArray['modified'] = date($dateFormat.' '.$timeFormat, $row['item_mtime']);
 
 		$pathId = $row['data_page_id']?$row['data_page_id']:$row['page_id'];
 		$pathMP = $row['data_page_id']?$row['data_page_mp']:'';
