@@ -27,7 +27,7 @@
 /**
  * Contains class with layout/output function for TYPO3 Backend Scripts
  *
- * $Id: template.php 1800 2006-11-17 18:49:26Z mundaun $
+ * $Id: template.php 1970 2007-02-04 15:50:25Z ingmars $
  * Revised for TYPO3 3.6 2/2003 by Kasper Skaarhoj
  * XHTML-trans compliant
  *
@@ -882,7 +882,7 @@ $str.=$this->docBodyTagBegin().
 	 * @return	string		HTML body tag
 	 */
 	function docBodyTagBegin()	{
-		$bodyContent = 'body '.trim($this->bodyTagAdditions.($this->bodyTagId ? ' id="'.$this->bodyTagId.'"' : ''));
+		$bodyContent = 'body onclick="if (top.menuReset) top.menuReset();" '.trim($this->bodyTagAdditions.($this->bodyTagId ? ' id="'.$this->bodyTagId.'"' : ''));
 		return '<'.trim($bodyContent).'>';
 	}
 
@@ -1212,9 +1212,9 @@ $str.=$this->docBodyTagBegin().
 		$opt=array();
 		if ($addSaveOptions)	{
 			$opt[]='<option value="">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.menu',1).'</option>';
-			$opt[]='<option value="TBE_EDITOR_checkAndDoSubmit(1);">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc',1).'</option>';
-			$opt[]='<option value="document.editform.closeDoc.value=-2; TBE_EDITOR_checkAndDoSubmit(1);">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseDoc',1).'</option>';
-			if ($BE_USER->uc['allSaveFunctions'])	$opt[]='<option value="document.editform.closeDoc.value=-3; TBE_EDITOR_checkAndDoSubmit(1);">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseAllDocs',1).'</option>';
+			$opt[]='<option value="TBE_EDITOR.checkAndDoSubmit(1);">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc',1).'</option>';
+			$opt[]='<option value="document.editform.closeDoc.value=-2; TBE_EDITOR.checkAndDoSubmit(1);">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseDoc',1).'</option>';
+			if ($BE_USER->uc['allSaveFunctions'])	$opt[]='<option value="document.editform.closeDoc.value=-3; TBE_EDITOR.checkAndDoSubmit(1);">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseAllDocs',1).'</option>';
 			$opt[]='<option value="document.editform.closeDoc.value=2; document.editform.submit();">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.closeDoc',1).'</option>';
 			$opt[]='<option value="document.editform.closeDoc.value=3; document.editform.submit();">'.$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.closeAllDocs',1).'</option>';
 			$opt[]='<option value=""></option>';
@@ -1249,7 +1249,7 @@ $str.=$this->docBodyTagBegin().
 			/*<![CDATA[*/
 					// is called from most clickmenu links
 				function showClickmenu(table, uid, listFr, enDisItems, backPath, addParams)	{
-					var url = "'.$this->backPath.'alt_clickmenu.php?table=" + table
+					var url = "'.$this->backPath.'alt_clickmenu.php?table=" + encodeURIComponent(table)
 					          + "&uid=" + uid
 										+ "&listFr=" + listFr
 										+ "&enDisItems=" + enDisItems
@@ -1271,12 +1271,6 @@ $str.=$this->docBodyTagBegin().
 		$content.= '
 				}
 
-	/**
-	 * [Describe function...]
-	 *
-	 * @param	[type]		$url: ...
-	 * @return	[type]		...
-	 */
 				function showClickmenu_noajax(url)	{
 					top.loadTopMenu(url);
 				}';
@@ -1309,6 +1303,7 @@ $str.=$this->docBodyTagBegin().
 					//browsercheck...
 				function GL_checkBrowser(){	//
 					this.dom= (document.getElementById);
+					this.safari =  (navigator.userAgent.indexOf("Safari")>-1);
 					this.op=  (navigator.userAgent.indexOf("Opera")>-1);
 					this.op7=  this.op && (navigator.appVersion.indexOf("7")>-1);  // check for Opera version 7
 					this.konq=  (navigator.userAgent.indexOf("Konq")>-1);
@@ -1347,9 +1342,13 @@ $str.=$this->docBodyTagBegin().
 
 						GLV_xRel = event.clientX-2;
 						GLV_yRel = event.clientY-2;
+						
+						GLV_x = GLV_xRel;
+						GLV_y = GLV_yRel;
+						
 						GLV_x = GLV_xRel + (document.documentElement.scrollLeft ? document.documentElement.scrollLeft : document.body.scrollLeft);
 						GLV_y = GLV_yRel + (document.documentElement.scrollTop ? document.documentElement.scrollTop : document.body.scrollTop);
-
+						
 					//	status = (GLV_x+GLV_gap-GLV_curLayerX[0]) + " | " + (GLV_y+GLV_gap-GLV_curLayerY[0]);
 						if (GLV_isVisible[1])	{
 							if (outsideLayer(1))	hideSpecific(1);
@@ -1682,7 +1681,7 @@ $str.=$this->docBodyTagBegin().
 			$options = array(array());
 			$divs = array();
 			$JSinit = array();
-			$id = 'DTM-'.t3lib_div::shortMD5($identString);
+			$id = $this->getDynTabMenuId($identString);
 			$noWrap = $noWrap ? ' nowrap="nowrap"' : '';
 
 				// Traverse menu items
@@ -1792,6 +1791,17 @@ $str.=$this->docBodyTagBegin().
 		}
 		return $content;
 	}
+	
+	/**
+	 * Creates the id for dynTabMenus.
+	 *
+	 * @param	string		$identString: Identification string. This should be unique for every instance of a dynamic menu!
+	 * @return	string		The id with a short MD5 of $identString and prefixed "DTM-", like "DTM-2e8791854a"
+	 */
+	function getDynTabMenuId($identString) {
+		$id = 'DTM-'.t3lib_div::shortMD5($identString);
+		return $id;
+	}
 
 	/**
 	 * Returns dynamic tab menu header JS code.
